/********************************************************************
*
*  Interface declaration for the Alcatel SpeedTouch USB ADSL modem.
*
* usage:
*  the management daemon opens a AF_UNIX socket on /tmp/.udsl0
*  send it a packet consisting of the udsl_request structure.
*  the command field is a flagfield consisting of the UDSL_GETDATA_* flags
*  the client field indicates the name of the receiving client socket.
*    of the form /tmp/.udsl_clientX with X the value of client.
*  you will receive a udsl_data_t structure with the requested data.
********************************************************************/

#define UDSL_GETDATA_STATUS      0x01
#define UDSL_GETDATA_BANDWIDTH   0x02
#define UDSL_GETDATA_ERRORS      0x04

typedef struct udsl_request {
  int               client;
  unsigned short    command;
  } udsl_request_t;

#define UDSL_STATUS_DOWN     0
#define UDSL_STATUS_UP       1

typedef struct udsl_data {
  unsigned short    command;      /* repeat of command request */
  unsigned short    status;       /* line status */
  unsigned long     upstream;     /* upstream bandwidth in bits/s */
  unsigned long     downstream;   /* downstream bandwidth in bits/s */
  unsigned short    err_phy_los;  /* error : loss of signal */
  unsigned short    err_phy_lof;  /* error : loss of frame  */
  unsigned short    errorred_secs;/* number of seconds in which errores occured */
  } udsl_data_t;
